@@ -1,3 +1,4 @@
+skip_if_not_installed("mlr3")
 skip_if_not_installed("rpart")
 skip_if_not_installed("partykit")
 skip_if_not_installed("ggparty")
@@ -6,5 +7,5 @@ test_that("autoplot.LearnerRegrRpart", {
   learner = mlr3::lrn("regr.rpart", keep_model = TRUE)$train(mlr3::tsk("mtcars"))
   p = autoplot(learner)
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("learner_regr.rpart", p)
+  expect_doppelganger("learner_regr.rpart", p)
 })
